'use strict'

/**
 * Module dependencies.
 */

const express = require('express');
const logger = require('morgan');
const path = require('path');
const fs = require('fs');
const YAML = require('yaml');
const app = express();

// log requests
app.use(logger('dev'));

app.use(express.json());

// express on its own has no notion
// of a "file". The express.static()
// middleware checks for a file matching
// the `req.path` within the directory
// that you pass it. In this case "GET /js/app.js"
// will look for "./public/js/app.js".

// app.use(express.static(path.join(__dirname, 'public')));

// if you wanted to "prefix" you may use
// the mounting feature of Connect, for example
// "GET /static/js/app.js" instead of "GET /js/app.js".
// The mount-path "/static" is simply removed before
// passing control to the express.static() middleware,
// thus it serves the file correctly by ignoring "/static"
app.use('/api/plugin/static', express.static(path.join(__dirname, 'dist'), {
  setHeaders: function (res, path, stat) {
    res.set('Access-Control-Allow-Origin', '*');
  }
}));

app.use('/api/plugin/AppsVersion', (req, res, next)=> {
  const data = fs.readFileSync(path.resolve(__dirname, './manifest.yml'), { encoding: 'utf8'});
  const env = fs.readFileSync(path.resolve(__dirname, './localEnv.yml'), { encoding: 'utf8'});
  res.send({
    ...YAML.parse(data),
    ...YAML.parse(env),
  });
});

app.listen(3000);
console.log('listening on port 3000');
